DeliveryDate class

Represents the "Leistungsdatum" in Germany. Represents the "Leistungszeitraum" if endDate is specified.

Constructors

DeliveryDate.date(DateTime date)
DeliveryDate.period(DateTime date, DateTime? endDate)

Properties

date DateTime
final
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited