InvoiceLineItem class

Represents a single line item for the Factur-X XML.

Constructors

InvoiceLineItem({required String lineId, required String name, required double unitPrice, required double quantity, String unitCode = 'C62', double? vatPercent, String vatCategoryCode = 'S', String? vatExemptionReason})

Properties

hashCode int
The hash code for this object.
no setterinherited
lineId String
Unique line identifier (e.g. "1", "2", ...).
final
lineTotal double
Line total (net): unitPrice * quantity.
no setter
name String
Human-readable product/service name.
final
quantity double
Quantity billed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unitCode String
Unit code per UN/ECE Recommendation 20. Common codes: "C62" = unit (piece), "HUR" = hour, "MON" = month, "DAY" = day, "H87" = piece, "MTK" = square metre, "KGM" = kilogram.
final
unitPrice double
Net unit price (before tax).
final
vatCategoryCode String
VAT category code. "S" = Standard rate, "Z" = Zero rate, "E" = Exempt, "AE" = Reverse charge, "K" = Intra-community.
final
vatExemptionReason String?
Required for Reverse Charge (AE).
final
vatPercent double
VAT rate in percent (e.g. 19.0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited