PaymentInfo class

Bank/payment information for the Factur-X XML.

Constructors

PaymentInfo({String typeCode = '58', required String iban, String? accountName, String? bic})

Properties

accountName String?
Account holder name (if different from seller name, optional).
final
bic String?
BIC/SWIFT code (optional for SEPA within EU).
final
hashCode int
The hash code for this object.
no setterinherited
iban String
IBAN of the seller's bank account.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeCode String
Payment means type code per UNTDID 4461. "58" = SEPA credit transfer, "30" = credit transfer (non-SEPA).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited