InvoiceItemList class
Constructors
-
InvoiceItemList({required List<
InvoiceLineItem> items})
Properties
- grandTotal → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
InvoiceLineItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → double
-
no setter
- totalTax → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited