InvoiceParty class
Seller / buyer party information for the Factur-X XML.
Constructors
Properties
- city → String
-
final
- countryCode → String
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- postcode → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- street → String
-
final
- taxId → String?
-
In Germany: Steuernummer (12/345/67890)
final
- taxIdSchemeId → String
-
"FC" or "IAN" (rarely used)
final
- vatId → String?
-
In Germany: Umsatzsteuer-ID (e.g. DE123456789)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited